# -*- coding: utf-8 -*-
"""In this files are tests, which tests the functionality of utility functions around the data model"""
import json
from pathlib import Path

from data_harvesting.util.data_model_util import apply_aggregator
from data_harvesting.util.data_model_util import convert_json_unhide

from helpers import TEST_DATA_DIR, sorted_json


def test_convert_json_unhide(tmp_path):
    """Convert a certain dir of jsonld data to unhide_json."""
    # source files to be converted
    TEST_DATA_SRC_PATH = TEST_DATA_DIR / 'util' / 'src'
    dest_dir = tmp_path  # temp dir to put resulting files

    def dest_file(filepath: Path):
        # reference result file for comparison (expected)
        return Path(str(filepath).replace('/src/', '/dest/').replace('.jsonld', '_unhide.json'))

    def res_file(filepath: Path):
        # file to be generated by function in this test
        return dest_dir / str(filepath.relative_to(TEST_DATA_SRC_PATH)).replace('.jsonld', '_unhide.json')

    convert_json_unhide(TEST_DATA_SRC_PATH, dest=dest_dir)

    for file_s in TEST_DATA_SRC_PATH.glob('*.jsonld'):
        file_d, file_r = dest_file(file_s), res_file(file_s)
        print(file_s, file_d, file_r)

        assert file_r.is_file()  # was created

        content = json.load(open(file_r, 'r', encoding='utf-8'))
        should = json.load(open(file_d, 'r', encoding='utf-8'))

        # print(content)
        content['metadata'] = should['metadata'] = {}  # because of uuids and time stamps
        assert sorted_json(content) == sorted_json(should)


def delete_time_fields(data):
    """Helper function to remove time fields from the data (for the purpose of testing)."""
    data['metadata'] = {}  # because of uuids and time stamps
    patch_stack = data.get('patch_stack', [])
    for i, patch in enumerate(data.get('patch_stack', [])):
        mda = patch.get('metadata', {})
        mda['creation_time'] = ''
        patch['metadata'] = mda
        patch_stack[i] = patch
    data['patch_stack'] = patch_stack

    return data


def test_apply_aggregator_dir(tmp_path):
    """Run the aggregator in full on a certain dir."""
    # source files to be uplifted
    TEST_DATA_AGGSRC_PATH = TEST_DATA_DIR / 'util' / 'agg_src'
    dest_dir = tmp_path  # temp dir to put resulting files
    test_config = TEST_DATA_AGGSRC_PATH / 'config.yaml'

    def dest_file(filepath: Path):
        # reference result file for comparison (expected)
        return Path(str(filepath).replace('/agg_src/', '/agg_dest/').replace('.json', '_uplifted.json'))

    def res_file(filepath: Path):
        # file to be generated by function in this test
        return dest_dir / str(filepath.relative_to(TEST_DATA_AGGSRC_PATH)).replace('.json', '_uplifted.json')

    apply_aggregator(TEST_DATA_AGGSRC_PATH, config=test_config, dest=dest_dir)

    for file_s in TEST_DATA_AGGSRC_PATH.glob('*.json'):
        file_r, file_d = res_file(file_s), dest_file(file_s)
        print(file_s, file_d, file_r)

        assert file_r.is_file()  # was created

        # load with json from file, or over LinkedData to get the python?
        content = json.load(open(file_r, 'r', encoding='utf-8'))
        should = json.load(open(file_d, 'r', encoding='utf-8'))

        assert content != {} and should != {}

        # ignore further time fields in patch metadata
        should = delete_time_fields(should)
        content = delete_time_fields(content)

        assert sorted_json(content) == sorted_json(should)
